@@ -9,22 +9,19 @@ from napoleontoolbox.file_saver import dropbox_file_saver
 import json
 
 class ForecasterParalleLauncher():
-    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', ss=[10], ns=[21], s_evals = [5], n_ffts=[21], n_wavelets=[21], calibration_steps=[1000],add_wavelet_details=[False], optimize_thresholds=[True], signal_idiosyncratic_paramaters=[None]):
+    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', ss=[10], ns=[21], s_evals = [5], calibration_steps=[1000], optimize_thresholds=[True], signal_idiosyncratic_paramaters=[None]):
         self.args = []
         self.counter = 1
         self.seed = 0
         for s in ss:
             for n in ns:
                 for s_eval in s_evals:
-                    for n_fft in n_ffts:
-                        for n_wavelet in n_wavelets:
-                            for add_wavelet_detail in add_wavelet_details:
-                                for calibration_step in calibration_steps:
-                                    for optimize_threshold in optimize_thresholds:
-                                        for signal_type, params  in signal_idiosyncratic_paramaters.items():
-                                            for param in params:
-                                                self.args.append((self,self.seed,n,s,s_eval,n_fft,n_wavelet,add_wavelet_detail,calibration_step,optimize_threshold,signal_type,json.dumps(param, sort_keys=True)))
-                                                self.counter = self.counter + 1
+                    for calibration_step in calibration_steps:
+                        for optimize_threshold in optimize_thresholds:
+                            for signal_type, params  in signal_idiosyncratic_paramaters.items():
+                                for param in params:
+                                    self.args.append((self,self.seed,n,s,s_eval,calibration_step,optimize_threshold,signal_type,json.dumps(param, sort_keys=True)))
+                                    self.counter = self.counter + 1
         self.args.sort()
         self.local_root_directory = local_root_directory
         self.user = user
