@@ -127,7 +127,7 @@ def compute_signal_perf_ind(data=None, initial_price = 1. , average_execution_co
     perf_strat = (data['non_adjusted_reconstituted_perf'].iloc[-1] - 1.) / 1.
     return average_turn_over, perf_under, perf_strat
 
-def compute_signals_kpi(data=None, mapping_data=None, print_turnover = False, keep_only_one_per_signal_family = False):
+def compute_signals_kpi(data=None, mapping_data=None, print_turnover = False, keep_only_one_per_signal_family = False, number_per_year = 252):
     hr_dic, json_dic = signal_result_analyzer.unjsonize_mapping_dataframe(mapping_data)
     all_signals = [col for col in data.columns if 'signal' in col]
     results_dic = {}
@@ -138,10 +138,10 @@ def compute_signals_kpi(data=None, mapping_data=None, print_turnover = False, ke
     for sig in all_signals:
         for transac_cost in [True, False]:
             temp_df = data[['close', sig]].copy()
-            temp_df = temp_df.rename(columns={sig: "signal"}, errors="raise")
+            temp_df = temp_df.rename(columns={sig: "signal"})
             freqly_df, average_turn_over = signal_utility.reconstitute_signal_perf(data=temp_df, transaction_cost=transac_cost,print_turnover=print_turnover)
-            sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period=252 * 24 * 60, from_ret=True)
-            sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period=252 * 24 * 60, from_ret=True)
+            sharpe_strat = metrics.sharpe(freqly_df['perf_return'].dropna(), period=number_per_year, from_ret=True)
+            sharpe_under = metrics.sharpe(freqly_df['close_return'].dropna(), period=number_per_year, from_ret=True)
             kpis.append(
                 {
                     'sharpe_under': sharpe_under,
